'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var semanticUiReact = require('semantic-ui-react');
var formik = require('formik');

var Form = function Form(props) {
  var _useFormikContext = formik.useFormikContext(),
      handleSubmit = _useFormikContext.handleSubmit;

  return React__default.createElement(semanticUiReact.Form, Object.assign({
    onSubmit: handleSubmit
  }, props));
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var Field = function Field(_ref) {
  var fast = _ref.fast,
      children = _ref.children,
      restProps = _objectWithoutPropertiesLoose(_ref, ["fast", "children"]);

  if (fast) {
    return React__default.createElement(formik.FastField, Object.assign({
      "data-testid": "fast-field"
    }, restProps), children);
  } else {
    return React__default.createElement(formik.Field, Object.assign({
      "data-testid": "field"
    }, restProps), children);
  }
};

var RESET_BUTTON_ID = 'formik-semantic-ui-react-reset-button';
var ResetButton = function ResetButton(_ref) {
  var _onClick = _ref.onClick,
      restProps = _objectWithoutPropertiesLoose(_ref, ["onClick"]);

  var formContext = formik.useFormikContext();
  return React__default.createElement(semanticUiReact.FormButton, Object.assign({
    id: RESET_BUTTON_ID,
    type: "button",
    onClick: function onClick(event, data) {
      formContext.resetForm();
      _onClick && _onClick(event, data);
    }
  }, restProps));
};

var SUBMIT_BUTTON_ID = 'formik-semantic-ui-react-submit-button';
var SubmitButton = function SubmitButton(_ref) {
  var disableLoading = _ref.disableLoading,
      loading = _ref.loading,
      restProps = _objectWithoutPropertiesLoose(_ref, ["disableLoading", "loading"]);

  var context = formik.useFormikContext();
  return React__default.createElement(semanticUiReact.FormButton, Object.assign({
    id: SUBMIT_BUTTON_ID,
    type: "submit",
    loading: disableLoading ? undefined : loading === null || loading === undefined ? context.isSubmitting : loading
  }, restProps));
};

var Input = function Input(_ref, ref) {
  var id = _ref.id,
      name = _ref.name,
      validate = _ref.validate,
      fast = _ref.fast,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      label = _ref.label,
      inputLabel = _ref.inputLabel,
      restProps = _objectWithoutPropertiesLoose(_ref, ["id", "name", "validate", "fast", "onChange", "onBlur", "errorPrompt", "errorConfig", "label", "inputLabel"]);

  var fieldLabelId = id && label && id + "-field-label" || undefined;
  var inputLabelId = id && inputLabel && id + "-input-label" || undefined;
  var fieldLabel = label && React__default.createElement("label", {
    id: fieldLabelId,
    htmlFor: id
  }, label);

  var errorLabel = function errorLabel(error) {
    var _errorConfig$prompt, _errorConfig$pointing;

    return React__default.createElement(semanticUiReact.Label, {
      id: id ? id + "-error-message" : undefined,
      role: "alert",
      "aria-atomic": true,
      content: error,
      prompt: (_errorConfig$prompt = errorConfig == null ? void 0 : errorConfig.prompt) != null ? _errorConfig$prompt : true,
      basic: errorConfig == null ? void 0 : errorConfig.basic,
      pointing: (_errorConfig$pointing = errorConfig == null ? void 0 : errorConfig.pointing) != null ? _errorConfig$pointing : true,
      color: errorConfig == null ? void 0 : errorConfig.color
    });
  };

  var errorLabelBefore = function errorLabelBefore(meta) {
    return errorPrompt && meta.touched && meta.error && ((errorConfig == null ? void 0 : errorConfig.pointing) === 'below' || (errorConfig == null ? void 0 : errorConfig.pointing) === 'right') && errorLabel(meta.error);
  };

  var errorLabelAfter = function errorLabelAfter(meta) {
    return errorPrompt && meta.touched && meta.error && ((errorConfig == null ? void 0 : errorConfig.pointing) === 'above' || (errorConfig == null ? void 0 : errorConfig.pointing) === 'left' || !(errorConfig == null ? void 0 : errorConfig.pointing)) && errorLabel(meta.error);
  };

  return React__default.createElement(Field, {
    name: name,
    validate: validate,
    fast: fast
  }, function (_ref2) {
    var _ref2$field = _ref2.field,
        value = _ref2$field.value,
        _onChange2 = _ref2$field.onChange,
        _onBlur2 = _ref2$field.onBlur,
        meta = _ref2.meta;
    return React__default.createElement(semanticUiReact.FormField, {
      error: meta.touched && !!meta.error
    }, fieldLabel, errorLabelBefore(meta), React__default.createElement(semanticUiReact.Input, Object.assign({
      id: id,
      ref: ref,
      name: name,
      value: value,
      label: formik.isString(inputLabel) && {
        children: inputLabel,
        htmlFor: id,
        id: inputLabelId
      } || formik.isObject(inputLabel) && _extends({}, inputLabel, {
        htmlFor: id,
        id: inputLabelId
      }),
      onChange: function onChange(event, data) {
        _onChange2(event);

        _onChange && _onChange(event, data);
      },
      onBlur: function onBlur(event) {
        if (event.relatedTarget instanceof Element) {
          /*
            Skip validation onBlur when reset / submit button is clicked or
            It will block reset / submit button onClick event
          */
          if (event.relatedTarget.id === RESET_BUTTON_ID || event.relatedTarget.id === SUBMIT_BUTTON_ID) {
            return;
          }
        }

        _onBlur2(event);
      },
      "aria-describedby": id && !!meta.error ? id + "-error-message" : null,
      "aria-invalid": !!meta.error ? true : undefined,
      "aria-labelledby": (fieldLabelId != null ? fieldLabelId : '') + " " + (inputLabelId != null ? inputLabelId : '')
    }, restProps)), errorLabelAfter(meta));
  });
};
var Input$1 = /*#__PURE__*/React.forwardRef(Input);

var defaultErrorConfig = {
  pointing: 'above'
};

function getErrorConfig(meta, errorPrompt, errorConfig) {
  return meta.error && meta.touched ? errorPrompt ? errorConfig ? _extends({
    content: meta.error
  }, errorConfig) : _extends({
    content: meta.error
  }, defaultErrorConfig) : true : null;
}

var TextArea = function TextArea(_ref, ref) {
  var name = _ref.name,
      validate = _ref.validate,
      fast = _ref.fast,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "fast", "onChange", "errorPrompt", "errorConfig"]);

  return React__default.createElement(Field, {
    name: name,
    validate: validate,
    fast: fast
  }, function (_ref2) {
    var _ref2$field = _ref2.field,
        value = _ref2$field.value,
        _onChange2 = _ref2$field.onChange,
        onBlur = _ref2$field.onBlur,
        meta = _ref2.meta;
    return React__default.createElement(semanticUiReact.FormField, Object.assign({
      control: semanticUiReact.TextArea,
      ref: ref,
      name: name,
      value: value,
      onChange: function onChange(event, data) {
        _onChange2(event);

        _onChange && _onChange(event, data);
      },
      onBlur: onBlur,
      error: getErrorConfig(meta, errorPrompt, errorConfig)
    }, restProps));
  });
};
var TextArea$1 = /*#__PURE__*/React.forwardRef(TextArea);

var Checkbox = function Checkbox(_ref) {
  var name = _ref.name,
      validate = _ref.validate,
      fast = _ref.fast,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "fast", "onChange", "errorPrompt", "errorConfig"]);

  return React__default.createElement(Field, {
    name: name,
    validate: validate,
    fast: fast
  }, function (_ref2) {
    var _ref2$field = _ref2.field,
        value = _ref2$field.value,
        onBlur = _ref2$field.onBlur,
        _ref2$form = _ref2.form,
        setFieldValue = _ref2$form.setFieldValue,
        setFieldTouched = _ref2$form.setFieldTouched,
        meta = _ref2.meta;
    return React__default.createElement(semanticUiReact.FormField, Object.assign({
      control: semanticUiReact.Checkbox,
      name: name,
      checked: value,
      onChange: function onChange(event, data) {
        setFieldValue(name, data.checked);
        setFieldTouched(name, true, false);
        _onChange && _onChange(event, data);
      },
      onBlur: onBlur,
      error: getErrorConfig(meta, errorPrompt, errorConfig)
    }, restProps));
  });
};

var Radio = function Radio(_ref) {
  var name = _ref.name,
      validate = _ref.validate,
      fast = _ref.fast,
      _value = _ref.value,
      _onChange = _ref.onChange,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "validate", "fast", "value", "onChange", "errorPrompt", "errorConfig"]);

  return React__default.createElement(Field, {
    name: name,
    validate: validate,
    fast: fast
  }, function (_ref2) {
    var _ref2$field = _ref2.field,
        value = _ref2$field.value,
        onBlur = _ref2$field.onBlur,
        _ref2$form = _ref2.form,
        setFieldValue = _ref2$form.setFieldValue,
        setFieldTouched = _ref2$form.setFieldTouched,
        meta = _ref2.meta;
    return React__default.createElement(semanticUiReact.FormField, Object.assign({
      control: semanticUiReact.Radio,
      name: name,
      checked: value === _value,
      value: _value,
      onChange: function onChange(event, data) {
        setFieldValue(name, _value);
        setFieldTouched(name, true, false);
        _onChange && _onChange(event, data);
      },
      onBlur: onBlur,
      error: getErrorConfig(meta, errorPrompt, errorConfig)
    }, restProps));
  });
};

var Select = function Select(_ref) {
  var name = _ref.name,
      options = _ref.options,
      validate = _ref.validate,
      fast = _ref.fast,
      _onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      errorPrompt = _ref.errorPrompt,
      errorConfig = _ref.errorConfig,
      restProps = _objectWithoutPropertiesLoose(_ref, ["name", "value", "options", "validate", "fast", "onChange", "onBlur", "errorPrompt", "errorConfig"]);

  return React__default.createElement(Field, {
    name: name,
    validate: validate,
    fast: fast
  }, function (_ref2) {
    var value = _ref2.field.value,
        _ref2$form = _ref2.form,
        setFieldValue = _ref2$form.setFieldValue,
        setFieldTouched = _ref2$form.setFieldTouched,
        meta = _ref2.meta;
    return React__default.createElement(semanticUiReact.FormField, Object.assign({
      control: semanticUiReact.Select,
      name: name,
      options: options,
      value: value,
      onChange: function onChange(event, data) {
        setFieldValue(name, data.value);
        setFieldTouched(name, true, false);
        _onChange && _onChange(event, data);
      },
      onBlur: onBlur,
      error: getErrorConfig(meta, errorPrompt, errorConfig)
    }, restProps));
  });
};

var FormikDebug = function FormikDebug(props) {
  return  React__default.createElement("pre", {
    style: _extends({
      padding: 15
    }, props),
    "data-testid": "debug"
  }, React__default.createElement(formik.Field, null, function (_ref) {
    var form = _ref.form;
    return JSON.stringify(form, null, 2);
  })) ;
};

exports.Checkbox = Checkbox;
exports.Field = Field;
exports.Form = Form;
exports.FormikDebug = FormikDebug;
exports.Input = Input$1;
exports.Radio = Radio;
exports.ResetButton = ResetButton;
exports.Select = Select;
exports.SubmitButton = SubmitButton;
exports.TextArea = TextArea$1;
//# sourceMappingURL=formik-semantic-ui-react.cjs.development.js.map
